@@ -1,4 +1,4 @@
-#if !defined (GDK_PIXBUF_H_INSIDE) && !defined (GDK_PIXBUF_COMPILATION)
+#if defined(GDK_PIXBUF_DISABLE_SINGLE_INCLUDES) && !defined (GDK_PIXBUF_H_INSIDE) && !defined (GDK_PIXBUF_COMPILATION)
 #error "Only <gdk-pixbuf/gdk-pixbuf.h> can be included directly."
 #endif
 
@@ -6,9 +6,9 @@
 #define GDK_PIXBUF_FEATURES_H 1
 
 #define GDK_PIXBUF_MAJOR (2)
-#define GDK_PIXBUF_MINOR (21)
-#define GDK_PIXBUF_MICRO (4)
-#define GDK_PIXBUF_VERSION "2.21.4"
+#define GDK_PIXBUF_MINOR (22)
+#define GDK_PIXBUF_MICRO (1)
+#define GDK_PIXBUF_VERSION "2.22.1"
 
 /* We prefix variable declarations so they can
  * properly get exported/imported from Windows DLLs.
